@@ -1,18 +1,12 @@
 use std::boxed::Box;
 
-use cargo_zigbuild::Zig;
+use cargo_lambda_build::{Build, Zig};
+use cargo_lambda_invoke::Invoke;
+use cargo_lambda_new::New;
+use cargo_lambda_watch::Watch;
 use clap::{Parser, Subcommand};
 use miette::{miette, Result};
 
-mod build;
-mod command;
-mod invoke;
-mod metadata;
-mod progress;
-mod start;
-mod toolchain;
-mod zig;
-
 #[derive(Parser)]
 #[clap(name = "cargo")]
 #[clap(bin_name = "cargo")]
@@ -29,11 +23,13 @@ enum App {
 #[clap(version)]
 pub enum Lambda {
     /// Build AWS Lambda functions compiled with zig as the linker
-    Build(Box<build::Build>),
+    Build(Box<Build>),
     /// Send requests to Lambda functions running on the emulator
-    Invoke(invoke::Invoke),
+    Invoke(Invoke),
+    /// Create a new package with a Lambda function from our Lambda Template
+    New(New),
     /// Start a Lambda Runtime emulator to test and debug functions locally
-    Start(start::Start),
+    Watch(Watch),
 }
 
 #[tokio::main]
@@ -43,7 +39,8 @@ async fn main() -> Result<()> {
         App::Lambda(lambda) => match *lambda {
             Lambda::Build(mut b) => b.run().await,
             Lambda::Invoke(i) => i.run().await,
-            Lambda::Start(s) => s.run().await,
+            Lambda::New(mut n) => n.run().await,
+            Lambda::Watch(w) => w.run().await,
         },
         App::Zig(zig) => zig.execute().map_err(|e| miette!(e)),
     }
